Learn R Programming

GGUM (version 0.5)

read.item.GGUM2004: Read 'GGUM2004' item estimates into R

Description

read.item.GGUM2004 reads the output files from 'GGUM2004' with the item parameters. Both the item parameter estimates and their standard errors are imported into R.

Usage

read.item.GGUM2004(temp.dir = "C:/GGUM2004/TEMPFILE", precision = 4)

Value

read.item.GGUM2004 returns a list cointaning the following components:

alpha

The estimated discrimination parameters (for GGUM).

delta

The estimated difficulty parameters.

taus

The estimated threshold parameters.

alphaSE

The standard errors for the estimated discrimination parameters (for GGUM).

deltaSE

The standard errors for the estimated difficulty parameters.

tausSE

The standard errors for the estimated threshold parameters (above zero; recall that the threshold parameters are constrained to symmetry around zero, that is, \(\tau_{i(C+1)}=0\) and \(\tau_{iz}=-\tau_{i(M-z+1)}\) for \(z\not= 0\).

Arguments

temp.dir

The directory where 'GGUM2004' saved the output. By default, it is "C:/GGUM2004/TEMPFILE".

precision

Number of decimal places of the results (default = 4).

Author

Sebastian Castro-Alvarez, secastroal@gmail.com

Details

Observe that this function is optimized for the Windows operating system because 'GGUM2004' is a Windows program.

References

Robertsetal2000GGUM

Robertsetal2006GGUM

Examples

Run this code
if (FALSE) {
# If the 'GGUM2004' output files are in the default directory 
# (C:/GGUM2004/TEMPFILE), then simply execute
read.item.GGUM2004()
}

Run the code above in your browser using DataLab