Learn R Programming

GGUM (version 0.5)

read.person.GGUM2004: Read 'GGUM2004' person estimates into R

Description

read.person.GGUM2004 reads the output files from 'GGUM2004' with the person parameters. Both the person parameter estimates and their standard errors are imported into R.

Usage

read.person.GGUM2004(temp.dir = "C:/GGUM2004/TEMPFILE", precision = 4)

Value

An \(N\times 3\) matrix is returned, where \(N\) is the number of persons. The first column is the person ID, the second column has the person parameter estimates, and the last column has the standard errors.

Arguments

temp.dir

The directory where 'GGUM2004' saved the output. By default, it is "C:/GGUM2004/TEMPFILE".

precision

Number of decimal places of the results (default = 4).

Author

Sebastian Castro-Alvarez, secastroal@gmail.com

Details

Observe that this function is optimized for the Windows operating system because 'GGUM2004' is a Windows program.

References

Robertsetal2006GGUM

Examples

Run this code
if (FALSE) {
# If the 'GGUM2004' output files are in the default directory 
# (C:/GGUM2004/TEMPFILE), then simply execute
read.person.GGUM2004()
}

Run the code above in your browser using DataLab